@@ -95,7 +95,7 @@ predict.mcmc_output <- function(object, future_model, type = "response",
   
   if (attr(object, "model_type") %in% c("bsm", "ng_bsm")) {
     object$theta[,1:(ncol(object$theta) - length(future_model$coefs))] <- 
-      log(1 + object$theta[,1:(ncol(object$theta) - length(future_model$coefs))])
+      log(object$theta[,1:(ncol(object$theta) - length(future_model$coefs))])
   }
   
   switch(attr(object, "model_type"),
